==> intel-media-driver-non-free_18.4.1%2Bds1.orig.tar.xz: media-driver-intel-media-18.4.1/media_driver/linux/common/codec/hal/codechal_secure_decode_interface.cpp <==
/*
* Copyright (c) 2013-2018, Intel Corporation
*
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included
* in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
* OTHER DEALINGS IN THE SOFTWARE.
*/
//!
//! \file      codechal_secure_decode_interface.cpp
//! \brief     Stub file for CodecHal Secure Decode 
//!

#include "codechal_secure_decode_interface.h"
#include "cplib_utils.h"

static void SecureDecodeStubMessage()
{
    MOS_NORMALMESSAGE(MOS_COMPONENT_CP, MOS_CP_SUBCOMP_CODEC, CP_STUB_MESSAGE);
}

CodechalSecureDecodeInterface *Create_SecureDecodeInterface(
    CodechalSetting *    codechalSettings,
    CodechalHwInterface *hwInterfaceInput)
{
    if(nullptr == codechalSettings || nullptr == hwInterfaceInput)
    {
        MOS_NORMALMESSAGE(MOS_COMPONENT_CP, MOS_CP_SUBCOMP_CODEC, "NULL pointer parameters");
        return nullptr;
    }

    CodechalSecureDecodeInterface *pCodechalSecureDecodeInterface = nullptr;
    using Create_SecureDecodeFuncType                     = CodechalSecureDecodeInterface *(*)(
        CodechalSetting * codecHalSettings, 
        CodechalHwInterface * hwInterfaceInput);

    CPLibUtils::InvokeCpFunc<Create_SecureDecodeFuncType>(
        pCodechalSecureDecodeInterface, 
        CPLibUtils::FUNC_CREATE_SECUREDECODE, 
        codechalSettings, 
        hwInterfaceInput);

    if(nullptr == pCodechalSecureDecodeInterface) SecureDecodeStubMessage();

    return pCodechalSecureDecodeInterface;
}

void Delete_SecureDecodeInterface(CodechalSecureDecodeInterface *pCodechalSecureDecodeInterface)
{
    if(pCodechalSecureDecodeInterface != nullptr)
    {
        using Delete_SecureDecodeFuncType = void (*)(CodechalSecureDecodeInterface* pCodechalSecureDecodeInterface);
        CPLibUtils::InvokeCpFunc<Delete_SecureDecodeFuncType>(CPLibUtils::FUNC_DELETE_SECUREDECODE, pCodechalSecureDecodeInterface);
    }
}

==> intel-media-driver-non-free_21.1.1%2Bds1.orig.tar.xz: media-driver-intel-media-21.1.1/media_driver/linux/common/codec/hal/codechal_secure_decode_interface.cpp <==
/*
* Copyright (c) 2013-2020, Intel Corporation
*
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included
* in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
* OTHER DEALINGS IN THE SOFTWARE.
*/
//!
//! \file      codechal_secure_decode_interface.cpp
//! \brief     Stub file for CodecHal Secure Decode
//!

#include "codechal_secure_decode_interface.h"
#include "cp_interfaces.h"

static void SecureDecodeStubMessage()
{
    MOS_NORMALMESSAGE(MOS_COMPONENT_CP, MOS_CP_SUBCOMP_CODEC, "This function is stubbed as CP is not enabled.");
}

CodechalSecureDecodeInterface *Create_SecureDecodeInterface(
    CodechalSetting *    codechalSettings,
    CodechalHwInterface *hwInterfaceInput)
{
    if (nullptr == codechalSettings || nullptr == hwInterfaceInput)
    {
        MOS_NORMALMESSAGE(MOS_COMPONENT_CP, MOS_CP_SUBCOMP_CODEC, "NULL pointer parameters");
        return nullptr;
    }

    CpInterfaces *cp_interface = CpInterfacesFactory::Create(CP_INTERFACE);
    if (nullptr == cp_interface)
    {
        MOS_NORMALMESSAGE(MOS_COMPONENT_CP, MOS_CP_SUBCOMP_CODEC, "NULL pointer parameters");
        return nullptr;
    }

    CodechalSecureDecodeInterface *pInterface = nullptr;
    pInterface = cp_interface->Create_SecureDecodeInterface(codechalSettings, hwInterfaceInput);
    MOS_Delete(cp_interface);

    if (nullptr == pInterface) SecureDecodeStubMessage();

    return pInterface;
}

void Delete_SecureDecodeInterface(CodechalSecureDecodeInterface *pInterface)
{
    CpInterfaces *cp_interface = CpInterfacesFactory::Create(CP_INTERFACE);
    if (pInterface != nullptr && cp_interface != nullptr)
    {
        cp_interface->Delete_SecureDecodeInterface(pInterface);
    }
    MOS_Delete(cp_interface);
}
